==> constructorio-ui-quizzes-1.9.7.tgz: package/lib/mjs/hooks/useQuizState/useQuizApiState.js <==
import { useEffect, useReducer } from 'react';
import { QuestionTypes, QuizAPIActionTypes, } from '../../components/CioQuiz/actions';
import apiReducer, { initialState, } from '../../components/CioQuiz/quizApiReducer';
import { getNextQuestion, getQuizResults } from '../../services';
const useQuizApiState = (quizOptions, cioClient, quizLocalState, skipToResults, dispatchLocalState
// eslint-disable-next-line max-params
) => {
    const [quizApiState, dispatchApiState] = useReducer(apiReducer, initialState);
    const { quizId, quizVersionId: quizVersionIdProp, resultsPageOptions } = quizOptions;
    const dispatchQuizResults = async () => {
        try {
            const quizResults = await getQuizResults(cioClient, quizId, {
                answers: quizLocalState.answers,
                resultsPerPage: resultsPageOptions?.numResultsToDisplay,
                quizVersionId: quizLocalState.quizVersionId,
                quizSessionId: quizLocalState.quizSessionId,
            });
            // Set quiz results state
            dispatchApiState({
                type: QuizAPIActionTypes.SET_QUIZ_RESULTS,
                payload: {
                    quizResults,
                },
            });
            if (!quizLocalState.isQuizCompleted)
                dispatchLocalState({
                    type: QuestionTypes.Complete,
                });
        }
        catch (error) {
            dispatchApiState({
                type: QuizAPIActionTypes.SET_IS_ERROR,
            });
        }
    };
    useEffect(() => {
        (async () => {
            dispatchApiState({
                type: QuizAPIActionTypes.SET_IS_LOADING,
            });
            if (skipToResults) {
                await dispatchQuizResults();
            }
            else {
                try {
                    const quizVersionId = quizLocalState.quizVersionId || quizVersionIdProp;
                    const { quizSessionId } = quizLocalState;
                    const questionResult = await getNextQuestion(cioClient, quizId, {
                        answers: quizLocalState.answers,
                        quizVersionId,
                        quizSessionId,
                    });
                    if (!questionResult.next_question) {
                        await dispatchQuizResults();
                        return;
                    }
                    // Update quizSessionId, quizVersionId
                    if ((!quizSessionId && questionResult?.quiz_session_id) ||
                        (!quizVersionId && questionResult.quiz_version_id)) {
                        dispatchLocalState({
                            type: QuestionTypes.Hydrate,
                            payload: {
                                quizVersionId: questionResult?.quiz_version_id,
                                quizSessionId: questionResult?.quiz_session_id,
                            },
                        });
                    }
                    // Set current question state
                    dispatchApiState({
                        type: QuizAPIActionTypes.SET_CURRENT_QUESTION,
                        payload: {
                            quizCurrentQuestion: questionResult,
                        },
                    });
                }
                catch (error) {
                    dispatchApiState({
                        type: QuizAPIActionTypes.SET_IS_ERROR,
                    });
                }
            }
        })();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [cioClient, quizId, quizLocalState.answers, resultsPageOptions?.numResultsToDisplay]);
    return {
        quizApiState,
        dispatchApiState,
    };
};
export default useQuizApiState;

==> constructorio-ui-quizzes-1.10.3.tgz: package/lib/mjs/hooks/useQuizState/useQuizApiState.js <==
import { useEffect, useReducer } from 'react';
import { QuestionTypes, QuizAPIActionTypes, } from '../../components/CioQuiz/actions';
import apiReducer, { initialState, } from '../../components/CioQuiz/quizApiReducer';
import { getNextQuestion, getQuizResults, getBrowseResultsForItemIds } from '../../services';
import useQueryParams from '../useQueryParams';
const useQuizApiState = (quizOptions, cioClient, quizLocalState, skipToResults, dispatchLocalState
// eslint-disable-next-line max-params
) => {
    const [quizApiState, dispatchApiState] = useReducer(apiReducer, initialState);
    const { quizId, quizVersionId: quizVersionIdProp, resultsPageOptions } = quizOptions;
    const { queryItems, queryAttributes, isSharedResultsQuery } = useQueryParams();
    const dispatchQuizResults = async () => {
        try {
            const quizResults = await getQuizResults(cioClient, quizId, {
                answers: quizLocalState.answers,
                resultsPerPage: resultsPageOptions?.numResultsToDisplay,
                quizVersionId: quizLocalState.quizVersionId,
                quizSessionId: quizLocalState.quizSessionId,
            });
            // Set quiz results state
            dispatchApiState({
                type: QuizAPIActionTypes.SET_QUIZ_RESULTS,
                payload: {
                    quizResults,
                },
            });
            if (!quizLocalState.isQuizCompleted)
                dispatchLocalState({
                    type: QuestionTypes.Complete,
                });
        }
        catch (error) {
            dispatchApiState({
                type: QuizAPIActionTypes.SET_IS_ERROR,
            });
        }
    };
    const dispatchSharedQuizResults = async () => {
        try {
            const quizResults = await getBrowseResultsForItemIds(cioClient, queryItems);
            dispatchApiState({
                type: QuizAPIActionTypes.SET_QUIZ_SHARED_RESULTS,
                payload: { quizResults: { ...quizResults, attributes: queryAttributes } },
            });
        }
        catch (error) {
            dispatchApiState({
                type: QuizAPIActionTypes.SET_IS_ERROR,
            });
        }
    };
    useEffect(() => {
        (async () => {
            dispatchApiState({
                type: QuizAPIActionTypes.SET_IS_LOADING,
            });
            if (isSharedResultsQuery) {
                await dispatchSharedQuizResults();
            }
            else if (skipToResults) {
                await dispatchQuizResults();
            }
            else {
                try {
                    const quizVersionId = quizLocalState.quizVersionId || quizVersionIdProp;
                    const { quizSessionId } = quizLocalState;
                    const questionResult = await getNextQuestion(cioClient, quizId, {
                        answers: quizLocalState.answers,
                        quizVersionId,
                        quizSessionId,
                    });
                    if (!questionResult.next_question) {
                        await dispatchQuizResults();
                        return;
                    }
                    // Update quizSessionId, quizVersionId
                    if ((!quizSessionId && questionResult?.quiz_session_id) ||
                        (!quizVersionId && questionResult.quiz_version_id)) {
                        dispatchLocalState({
                            type: QuestionTypes.Hydrate,
                            payload: {
                                quizVersionId: questionResult?.quiz_version_id,
                                quizSessionId: questionResult?.quiz_session_id,
                            },
                        });
                    }
                    // Set current question state
                    dispatchApiState({
                        type: QuizAPIActionTypes.SET_CURRENT_QUESTION,
                        payload: {
                            quizCurrentQuestion: questionResult,
                        },
                    });
                }
                catch (error) {
                    dispatchApiState({
                        type: QuizAPIActionTypes.SET_IS_ERROR,
                    });
                }
            }
        })();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [
        cioClient,
        quizId,
        quizLocalState.answers,
        resultsPageOptions?.numResultsToDisplay,
        isSharedResultsQuery,
    ]);
    return {
        quizApiState,
        dispatchApiState,
    };
};
export default useQuizApiState;
